package com.yanzhu.jh.project.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.yanzhu.jh.project.domain.SurProject;
import com.yanzhu.jh.project.domain.SurProjectUnitInfo;
import com.yanzhu.jh.project.domain.SurProjectUserinfo;

/**
 * 项目用户Service接口
 * 
 * @author JiangYuQi
 * @date 2023-07-29
 */
public interface ISurProjectUserinfoService 
{
    /**
     * 查询项目用户
     * 
     * @param id 项目用户主键
     * @return 项目用户
     */
    public SurProjectUserinfo selectSurProjectUserinfoById(Long id);

    /**
     * 查询项目用户列表
     * 
     * @param surProjectUserinfo 项目用户
     * @return 项目用户集合
     */
    public List<SurProjectUserinfo> selectSurProjectUserinfoList(SurProjectUserinfo surProjectUserinfo);

    /**
     * 查询项目部门人员
     *
     * @param surProjectUserinfo 项目用户
     * @return 项目用户集合
     */
    public List<SurProjectUnitInfo> selectProjectUnitUser(SurProjectUserinfo surProjectUserinfo);

    /**
     * 查询项目相关人员
     *
     * @param projectId 项目主键
     * @param loginName 项目用户
     * @return 项目用户集合
     */
    public List<SurProjectUnitInfo> queryAllProjectUserInfo(Long projectId, String loginName);

    /**
     * 新增项目用户
     * 
     * @param surProjectUserinfo 项目用户
     * @return 结果
     */
    public int insertSurProjectUserinfo(SurProjectUserinfo surProjectUserinfo);

    /**
     * 修改项目用户
     * 
     * @param surProjectUserinfo 项目用户
     * @return 结果
     */
    public int updateSurProjectUserinfo(SurProjectUserinfo surProjectUserinfo);

    /**
     * 批量删除项目用户
     * 
     * @param ids 需要删除的项目用户主键集合
     * @return 结果
     */
    public int deleteSurProjectUserinfoByIds(Long[] ids);

    /**
     * 删除项目用户信息
     * 
     * @param id 项目用户主键
     * @return 结果
     */
    public int deleteSurProjectUserinfoById(Long id);

    /**
     * 根据条件分页查询用户列表
     *
     * @param surProject 项目信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectProjectUserList(SurProject surProject);
}
